[llvm-commits] [llvm] r102865 - in /llvm/trunk: docs/ docs/CommandGuide/ examples/ExceptionDemo/ include/llvm/Target/ lib/ExecutionEngine/JIT/ lib/Target/ test/CodeGen/ARM/ test/CodeGen/Generic/ test/CodeGen/PowerPC/ test/CodeGen/X86/ tools/lto/

Duncan Sands baldrick at free.fr
Sun May 2 08:36:26 PDT 2010


Author: baldrick
Date: Sun May  2 10:36:26 2010
New Revision: 102865

URL: http://llvm.org/viewvc/llvm-project?rev=102865&view=rev
Log:
Remove the -enable-sjlj-eh option, which doesn't do anything.
Remove the -enable-eh option which is only used by the JIT,
and replace it with -jit-enable-eh.

Modified:
    llvm/trunk/docs/CommandGuide/lli.pod
    llvm/trunk/docs/HowToSubmitABug.html
    llvm/trunk/examples/ExceptionDemo/ExceptionDemo.cpp
    llvm/trunk/include/llvm/Target/TargetOptions.h
    llvm/trunk/lib/ExecutionEngine/JIT/JITEmitter.cpp
    llvm/trunk/lib/Target/TargetMachine.cpp
    llvm/trunk/test/CodeGen/ARM/2007-05-07-tailmerge-1.ll
    llvm/trunk/test/CodeGen/ARM/2007-05-09-tailmerge-2.ll
    llvm/trunk/test/CodeGen/ARM/2007-05-22-tailmerge-3.ll
    llvm/trunk/test/CodeGen/Generic/2007-05-03-EHTypeInfo.ll
    llvm/trunk/test/CodeGen/Generic/2007-12-17-InvokeAsm.ll
    llvm/trunk/test/CodeGen/Generic/2007-12-31-UnusedSelector.ll
    llvm/trunk/test/CodeGen/PowerPC/2007-11-16-landingpad-split.ll
    llvm/trunk/test/CodeGen/X86/2007-05-05-Personality.ll
    llvm/trunk/test/CodeGen/X86/2007-05-07-InvokeSRet.ll
    llvm/trunk/test/CodeGen/X86/2007-06-04-tailmerge4.ll
    llvm/trunk/test/CodeGen/X86/2007-09-17-ObjcFrameEH.ll
    llvm/trunk/tools/lto/LTOCodeGenerator.cpp

Modified: llvm/trunk/docs/CommandGuide/lli.pod
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/docs/CommandGuide/lli.pod?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/docs/CommandGuide/lli.pod (original)
+++ llvm/trunk/docs/CommandGuide/lli.pod Sun May  2 10:36:26 2010
@@ -145,9 +145,9 @@
 
 Make the -lowerinvoke pass insert expensive, but correct, EH code.
 
-=item B<-enable-eh> 
+=item B<-jit-enable-eh> 
 
-Exception handling should be emitted.
+Exception handling should be enabled in the just-in-time compiler.
 
 =item B<-join-liveintervals> 
 

Modified: llvm/trunk/docs/HowToSubmitABug.html
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/docs/HowToSubmitABug.html?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/docs/HowToSubmitABug.html (original)
+++ llvm/trunk/docs/HowToSubmitABug.html Sun May  2 10:36:26 2010
@@ -186,9 +186,6 @@
 <li><tt><b>llc</b> foo.bc</tt></li>
 <li><tt><b>llc</b> foo.bc -relocation-model=pic</tt></li>
 <li><tt><b>llc</b> foo.bc -relocation-model=static</tt></li>
-<li><tt><b>llc</b> foo.bc -enable-eh</tt></li>
-<li><tt><b>llc</b> foo.bc -relocation-model=pic -enable-eh</tt></li>
-<li><tt><b>llc</b> foo.bc -relocation-model=static -enable-eh</tt></li>
 </ol>
 
 <p>If none of these crash, please follow the instructions for a
@@ -202,11 +199,6 @@
            -relocation-model=pic</tt></li>
 <li><tt><b>bugpoint</b> -run-llc foo.bc --tool-args
            -relocation-model=static</tt></li>
-<li><tt><b>bugpoint</b> -run-llc foo.bc --tool-args -enable-eh</tt></li>
-<li><tt><b>bugpoint</b> -run-llc foo.bc --tool-args
-           -relocation-model=pic -enable-eh</tt></li>
-<li><tt><b>bugpoint</b> -run-llc foo.bc --tool-args
-           -relocation-model=static -enable-eh</tt></li>
 </ol>
 
 <p>Please run this, then file a bug with the instructions and reduced .bc file

Modified: llvm/trunk/examples/ExceptionDemo/ExceptionDemo.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/examples/ExceptionDemo/ExceptionDemo.cpp?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/examples/ExceptionDemo/ExceptionDemo.cpp (original)
+++ llvm/trunk/examples/ExceptionDemo/ExceptionDemo.cpp Sun May  2 10:36:26 2010
@@ -1948,7 +1948,7 @@
     }
 
     // If not set, exception handling will not be turned on
-    llvm::DwarfExceptionHandling = true;
+    llvm::JITExceptionHandling = true;
 
     llvm::InitializeNativeTarget();
     llvm::LLVMContext& context = llvm::getGlobalContext();

Modified: llvm/trunk/include/llvm/Target/TargetOptions.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Target/TargetOptions.h?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/lib/ExecutionEngine/JIT/JITEmitter.cpp (original)
+++ llvm/trunk/lib/ExecutionEngine/JIT/JITEmitter.cpp Sun May  2 10:36:26 2010
@@ -384,7 +384,7 @@
         DEBUG(dbgs() << "JIT is managing a GOT\n");
       }
 
-      if (DwarfExceptionHandling || JITEmitDebugInfo) {
+      if (JITExceptionHandling || JITEmitDebugInfo) {
         DE.reset(new JITDwarfEmitter(jit));
       }
       if (JITEmitDebugInfo) {
@@ -1259,7 +1259,7 @@
       }
     });
 
-  if (DwarfExceptionHandling || JITEmitDebugInfo) {
+  if (JITExceptionHandling || JITEmitDebugInfo) {
     uintptr_t ActualSize = 0;
     SavedBufferBegin = BufferBegin;
     SavedBufferEnd = BufferEnd;
@@ -1282,7 +1282,7 @@
     BufferEnd = SavedBufferEnd;
     CurBufferPtr = SavedCurBufferPtr;
 
-    if (DwarfExceptionHandling) {
+    if (JITExceptionHandling) {
       TheJIT->RegisterTable(FrameRegister);
     }
 

Modified: llvm/trunk/lib/Target/TargetMachine.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/TargetMachine.cpp?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/lib/Target/TargetMachine.cpp (original)
+++ llvm/trunk/lib/Target/TargetMachine.cpp Sun May  2 10:36:26 2010
@@ -36,8 +36,7 @@
   FloatABI::ABIType FloatABIType;
   bool NoImplicitFloat;
   bool NoZerosInBSS;
-  bool DwarfExceptionHandling;
-  bool SjLjExceptionHandling;
+  bool JITExceptionHandling;
   bool JITEmitDebugInfo;
   bool JITEmitDebugInfoToDisk;
   bool UnwindTablesMandatory;
@@ -115,14 +114,9 @@
   cl::location(NoZerosInBSS),
   cl::init(false));
 static cl::opt<bool, true>
-EnableDwarfExceptionHandling("enable-eh",
-  cl::desc("Emit DWARF exception handling (default if target supports)"),
-  cl::location(DwarfExceptionHandling),
-  cl::init(false));
-static cl::opt<bool, true>
-EnableSjLjExceptionHandling("enable-sjlj-eh",
-  cl::desc("Emit SJLJ exception handling (default if target supports)"),
-  cl::location(SjLjExceptionHandling),
+EnableJITExceptionHandling("jit-enable-eh",
+  cl::desc("Emit exception handling information"),
+  cl::location(JITExceptionHandling),
   cl::init(false));
 // In debug builds, make this default to true.
 #ifdef NDEBUG

Modified: llvm/trunk/test/CodeGen/ARM/2007-05-07-tailmerge-1.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/ARM/2007-05-07-tailmerge-1.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/ARM/2007-05-07-tailmerge-1.ll (original)
+++ llvm/trunk/test/CodeGen/ARM/2007-05-07-tailmerge-1.ll Sun May  2 10:36:26 2010
@@ -1,7 +1,5 @@
 ; RUN: llc < %s -march=arm -enable-tail-merge | grep bl.*baz | count 1
 ; RUN: llc < %s -march=arm -enable-tail-merge | grep bl.*quux | count 1
-; RUN: llc < %s -march=arm -enable-tail-merge -enable-eh | grep bl.*baz | count 1
-; RUN: llc < %s -march=arm -enable-tail-merge -enable-eh | grep bl.*quux | count 1
 ; Check that calls to baz and quux are tail-merged.
 ; PR1628
 

Modified: llvm/trunk/test/CodeGen/ARM/2007-05-09-tailmerge-2.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/ARM/2007-05-09-tailmerge-2.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/ARM/2007-05-09-tailmerge-2.ll (original)
+++ llvm/trunk/test/CodeGen/ARM/2007-05-09-tailmerge-2.ll Sun May  2 10:36:26 2010
@@ -1,7 +1,5 @@
 ; RUN: llc < %s -march=arm -enable-tail-merge | grep bl.*baz | count 1
 ; RUN: llc < %s -march=arm -enable-tail-merge | grep bl.*quux | count 1
-; RUN: llc < %s -march=arm -enable-tail-merge -enable-eh | grep bl.*baz | count 1
-; RUN: llc < %s -march=arm -enable-tail-merge -enable-eh | grep bl.*quux | count 1
 ; Check that calls to baz and quux are tail-merged.
 ; PR1628
 

Modified: llvm/trunk/test/CodeGen/ARM/2007-05-22-tailmerge-3.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/ARM/2007-05-22-tailmerge-3.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/ARM/2007-05-22-tailmerge-3.ll (original)
+++ llvm/trunk/test/CodeGen/ARM/2007-05-22-tailmerge-3.ll Sun May  2 10:36:26 2010
@@ -2,10 +2,6 @@
 ; RUN: llc < %s -march=arm | grep bl.*quux | count 1
 ; RUN: llc < %s -march=arm -enable-tail-merge=0 | grep bl.*baz | count 2
 ; RUN: llc < %s -march=arm -enable-tail-merge=0 | grep bl.*quux | count 2
-; RUN: llc < %s -march=arm -enable-eh | grep bl.*baz | count 1
-; RUN: llc < %s -march=arm -enable-eh | grep bl.*quux | count 1
-; RUN: llc < %s -march=arm -enable-tail-merge=0 -enable-eh | grep bl.*baz | count 2
-; RUN: llc < %s -march=arm -enable-tail-merge=0 -enable-eh | grep bl.*quux | count 2
 ; Check that tail merging is the default on ARM, and that -enable-tail-merge=0 works.
 ; PR1628
 

Modified: llvm/trunk/test/CodeGen/Generic/2007-05-03-EHTypeInfo.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/Generic/2007-05-03-EHTypeInfo.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/Generic/2007-05-03-EHTypeInfo.ll (original)
+++ llvm/trunk/test/CodeGen/Generic/2007-05-03-EHTypeInfo.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -enable-eh
+; RUN: llc < %s
 
 	%struct.exception = type { i8, i8, i32, i8*, i8*, i32, i8* }
 @program_error = external global %struct.exception		; <%struct.exception*> [#uses=1]

Modified: llvm/trunk/test/CodeGen/Generic/2007-12-17-InvokeAsm.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/Generic/2007-12-17-InvokeAsm.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/Generic/2007-12-17-InvokeAsm.ll (original)
+++ llvm/trunk/test/CodeGen/Generic/2007-12-17-InvokeAsm.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -enable-eh
+; RUN: llc < %s
 
 define fastcc void @bc__support__high_resolution_time__initialize_clock_rate() {
 entry:

Modified: llvm/trunk/test/CodeGen/Generic/2007-12-31-UnusedSelector.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/Generic/2007-12-31-UnusedSelector.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/Generic/2007-12-31-UnusedSelector.ll (original)
+++ llvm/trunk/test/CodeGen/Generic/2007-12-31-UnusedSelector.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -enable-eh
+; RUN: llc < %s
 ; PR1833
 
 	%struct.__class_type_info_pseudo = type { %struct.__type_info_pseudo }

Modified: llvm/trunk/test/CodeGen/PowerPC/2007-11-16-landingpad-split.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/PowerPC/2007-11-16-landingpad-split.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/PowerPC/2007-11-16-landingpad-split.ll (original)
+++ llvm/trunk/test/CodeGen/PowerPC/2007-11-16-landingpad-split.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -enable-eh
+; RUN: llc < %s
 ;; Formerly crashed, see PR 1508
 target datalayout = "E-p:64:64:64-i1:8:8-i8:8:8-i16:16:16-i32:32:32-i64:32:64-f32:32:32-f64:32:64-v64:64:64-v128:128:128-a0:0:64-f128:64:128"
 target triple = "powerpc64-apple-darwin8"

Modified: llvm/trunk/test/CodeGen/X86/2007-05-05-Personality.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/X86/2007-05-05-Personality.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/X86/2007-05-05-Personality.ll (original)
+++ llvm/trunk/test/CodeGen/X86/2007-05-05-Personality.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -mtriple=i686-pc-linux-gnu -enable-eh -o - | grep zPL
+; RUN: llc < %s -mtriple=i686-pc-linux-gnu -o - | grep zPL
 
 @error = external global i8		; <i8*> [#uses=2]
 

Modified: llvm/trunk/test/CodeGen/X86/2007-05-07-InvokeSRet.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/X86/2007-05-07-InvokeSRet.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/X86/2007-05-07-InvokeSRet.ll (original)
+++ llvm/trunk/test/CodeGen/X86/2007-05-07-InvokeSRet.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -mtriple=i686-pc-linux-gnu -enable-eh -disable-fp-elim | not grep {addl .12, %esp}
+; RUN: llc < %s -mtriple=i686-pc-linux-gnu -disable-fp-elim | not grep {addl .12, %esp}
 ; PR1398
 
 	%struct.S = type { i32, i32 }

Modified: llvm/trunk/test/CodeGen/X86/2007-06-04-tailmerge4.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/X86/2007-06-04-tailmerge4.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/X86/2007-06-04-tailmerge4.ll (original)
+++ llvm/trunk/test/CodeGen/X86/2007-06-04-tailmerge4.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -enable-eh -asm-verbose | grep invcont131
+; RUN: llc < %s -asm-verbose | grep invcont131
 ; PR 1496:  tail merge was incorrectly removing this block
 
 ; ModuleID = 'report.1.bc'

Modified: llvm/trunk/test/CodeGen/X86/2007-09-17-ObjcFrameEH.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/X86/2007-09-17-ObjcFrameEH.ll?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/X86/2007-09-17-ObjcFrameEH.ll (original)
+++ llvm/trunk/test/CodeGen/X86/2007-09-17-ObjcFrameEH.ll Sun May  2 10:36:26 2010
@@ -1,4 +1,4 @@
-; RUN: llc < %s -march=x86 -mtriple=i686-apple-darwin -enable-eh  | grep {isNullOrNil].eh"} | count 2
+; RUN: llc < %s -march=x86 -mtriple=i686-apple-darwin | grep {isNullOrNil].eh"} | count 2
 
 	%struct.NSString = type {  }
 	%struct._objc__method_prototype_list = type opaque

Modified: llvm/trunk/tools/lto/LTOCodeGenerator.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/tools/lto/LTOCodeGenerator.cpp?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================
--- llvm/trunk/tools/lto/LTOCodeGenerator.cpp (original)
+++ llvm/trunk/tools/lto/LTOCodeGenerator.cpp Sun May  2 10:36:26 2010
@@ -353,20 +353,6 @@
 
     Module* mergedModule = _linker.getModule();
 
-    // If target supports exception handling then enable it now.
-    switch (_target->getMCAsmInfo()->getExceptionHandlingType()) {
-    case ExceptionHandling::Dwarf:
-      llvm::DwarfExceptionHandling = true;
-      break;
-    case ExceptionHandling::SjLj:
-      llvm::SjLjExceptionHandling = true;
-      break;
-    case ExceptionHandling::None:
-      break;
-    default:
-      assert (0 && "Unknown exception handling model!");
-    }
-
     // if options were requested, set them
     if ( !_codegenOptions.empty() )
         cl::ParseCommandLineOptions(_codegenOptions.size(), 





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/Target/TargetOptions.h (original)
+++ llvm/trunk/include/llvm/Target/TargetOptions.h Sun May  2 10:36:26 2010
@@ -107,13 +107,9 @@
   /// crt*.o compiling).
   extern bool NoZerosInBSS;
 
-  /// DwarfExceptionHandling - This flag indicates that Dwarf exception
-  /// information should be emitted.
-  extern bool DwarfExceptionHandling;
-
-  /// SjLjExceptionHandling - This flag indicates that SJLJ exception
-  /// information should be emitted.
-  extern bool SjLjExceptionHandling;
+  /// JITExceptionHandling - This flag indicates that the JIT should emit
+  /// exception handling information.
+  extern bool JITExceptionHandling;
 
   /// JITEmitDebugInfo - This flag indicates that the JIT should try to emit
   /// debug information and notify a debugger about it.

Modified: llvm/trunk/lib/ExecutionEngine/JIT/JITEmitter.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/ExecutionEngine/JIT/JITEmitter.cpp?rev=102865&r1=102864&r2=102865&view=diff
==============================================================================